@@ -7,6 +7,7 @@ Usage: %s [options]
 Options:
 -c/--configuration FILENAME -- configuration file path (searches if not given)
 -n/--nodaemon -- run in the foreground (same as 'nodaemon=true' in config file)
+-s/--silent -- no logs to stdout (maps to 'silent=true' in config file)
 -h/--help -- print this usage message and exit
 -v/--version -- print supervisord version number and exit
 -u/--user USER -- run supervisord as this user (or numeric uid)
@@ -38,6 +39,7 @@ from supervisor.medusa import asyncore_25 as asyncore
 
 from supervisor.compat import as_string
 from supervisor.options import ServerOptions
+from supervisor.options import decode_wait_status
 from supervisor.options import signame
 from supervisor import events
 from supervisor.states import SupervisorStates
@@ -82,7 +84,6 @@ class Supervisor:
         try:
             for config in self.options.process_group_configs:
                 self.add_process_group(config)
-            self.options.process_environment()
             self.options.openhttpservers(self)
             self.options.setsignals()
             if (not self.options.nodaemon) and self.options.first:
@@ -94,9 +95,8 @@ class Supervisor:
         finally:
             self.options.cleanup()
 
-    def diff_to_active(self, new=None):
-        if not new:
-            new = self.options.process_group_configs
+    def diff_to_active(self):
+        new = self.options.process_group_configs
         cur = [group.config for group in self.process_groups.values()]
 
         curdict = dict(zip([cfg.name for cfg in cur], cur))
@@ -275,7 +275,8 @@ class Supervisor:
         if pid:
             process = self.options.pidhistory.get(pid, None)
             if process is None:
-                self.options.logger.info('reaped unknown pid %s' % pid)
+                _, msg = decode_wait_status(sts)
+                self.options.logger.info('reaped unknown pid %s (%s)' % (pid, msg))
             else:
                 process.finish(pid, sts)
                 del self.options.pidhistory[pid]
